Command

Struct Command 

#[non_exhaustive]
pub struct Command { pub input: String, pub format: Option<String>, pub timezone: Option<String>, pub now: Option<Timestamp>, pub json: bool, pub no_newline: bool, pub verbose: bool, pub skip_errors: bool, }
Normalised user command ready for further processing.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
input: Stringformat: Option<String>timezone: Option<String>now: Option<Timestamp>json: boolno_newline: boolverbose: boolskip_errors: bool

Implementations

Source

impl Command

pub fn with_input(&self, input: String) -> Self

Create a new Command with a different input, preserving all other fields. Used in batch mode to avoid manual field cloning.

Source

impl Command

pub fn parse_from<I, S, R>( args: I, stdin: R, stdin_is_terminal: bool, ) -> Result<Self>
where I: IntoIterator<Item = S>, S: Into<OsString> + Clone, R: Read,

Parse from arbitrary arg iterator and an arbitrary reader for STDIN. The stdin_is_terminal flag controls whether we attempt to read from the reader when no positional argument is given.

pub fn parse() -> Result<Self>

Parse using the real env::args_os() and the real io::stdin().

pub fn from_raw_cli<R: Read>( cli: Cli, stdin: R, stdin_is_terminal: bool, ) -> Result<Self>

Converts a Cli into Command, reading STDIN if necessary.