Config

Struct Config 

#[non_exhaustive]
pub struct Config { pub format: String, pub timezone: String, pub formats: Option<HashMap<String, String>>, }
In-memory representation of the user configuration.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
format: String

Default output format (ISO-8601 by default).

timezone: String

Time-zone identifier (IANA name, e.g. "America/Sao_Paulo").

formats: Option<HashMap<String, String>>

User-defined named formats.

Implementations

Source

impl Config

pub fn load() -> Result<Self>

Load the effective configuration, creating the file from the embedded template if it does not yet exist.

pub fn presets(&self) -> Vec<Preset>

Convert the [formats] table into a list of Presets.