App

Struct App 

#[non_exhaustive]
pub struct App { pub date: String, pub format: String, pub timezone: TimeZone, pub now: Option<Zoned>, }
Immutable application context passed to process.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
date: String

Raw human-readable expression (e.g. "next Friday 10 am").

format: String

Either a strftime-style format string or the name of a preset.

timezone: TimeZone

Target time-zone for output.

now: Option<Zoned>

Optional “now” (useful for deterministic tests).

Implementations

Source

impl App

pub fn new( date: String, format: String, timezone: TimeZone, now: Option<Zoned>, ) -> Self

pub fn from_cli(cmd: &Command, cfg: &Config) -> Result<Self>

Build an App from the parsed CLI and loaded configuration.

  • CLI values override config values.
  • If no time-zone is provided anywhere, falls back to the OS local TZ.