Failable

Trait Failable 

pub trait Failable:
    Error
    + Send
    + Sync
    + 'static {
    // Required method
    fn exit(self) -> !;
}
Any fatal error that can terminate the application.

Implementations must emit an error message to stderr and terminate the process with a meaningful exit code.

Required Methods

fn exit(self) -> !

Print a diagnostic message and stop the program.

Implementors