#[non_exhaustive]pub struct Command {
pub input: String,
pub format: Option<String>,
pub timezone: Option<String>,
pub now: Option<Timestamp>,
pub json: bool,
pub no_newline: bool,
pub verbose: bool,
pub skip_errors: bool,
}Expand description
Normalised user command ready for further processing.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.input: Stringformat: Option<String>timezone: Option<String>now: Option<Timestamp>json: boolno_newline: boolverbose: boolskip_errors: boolImplementations
Sourceimpl Command
impl Command
Sourcepub fn with_input(&self, input: String) -> Self
pub fn with_input(&self, input: String) -> Self
Create a new Command with a different input, preserving all other fields. Used in batch mode to avoid manual field cloning.