pub trait Failable:
Error
+ Send
+ Sync
+ 'static {
// Required method
fn exit(self) -> !;
}Expand description
Any fatal error that can terminate the application.
Implementations must emit an error message to stderr and terminate the process with a meaningful exit code.